@@ -45,6 +45,8 @@ require Exporter;
 require DynaLoader;
 use Win32::WinError;
 
+require Win32 unless defined &Win32::GetLastError;
+
 use vars qw($VERSION $AUTOLOAD @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 $VERSION = '0.07';
@@ -145,7 +147,7 @@ sub AUTOLOAD {
     my($constname);
     ($constname = $AUTOLOAD) =~ s/.*:://;
     #reset $! to zero to reset any current errors.
-    $!=0;
+    local $! = 0;
     my $val = constant($constname, 0);
     if ($! != 0) {
 	if ($! =~ /Invalid/) {
